@@ -19,7 +19,7 @@ Usage
   #!/usr/bin/env python3
 
   from flask import Flask
-  from flask_gordon.ext import ArgParse
+  from flask_gordon.ext import ArgParseExt
 
   flask = Flask(__name__)
   flask = ArgParseExt(flask)
@@ -28,7 +28,7 @@ Usage
 Classes
 =======
 
-.. autoclass:: ArgParse
+.. autoclass:: ArgParseExt
    :members: __init__, init_app
 
 """
@@ -70,7 +70,7 @@ def _read(cfgfile: str) -> t.Dict[str, t.Any]:
     return data or {}
 
 
-class ArgParse:
+class ArgParseExt:
     def __init__(
         self,
         app: "FlaskApp" = None,
@@ -139,7 +139,7 @@ class ArgParse:
 
     def init_app(
         self,
-        app: "Flask" = None,
+        app: "Flask",
         middleware: str = "gunicorn",
         argv: t.List[str] = None,
         cfgfilename=None,
@@ -206,9 +206,10 @@ class ArgParse:
         cfg = deepmerge(cfg, arguments)
         cfg = helper.force_cfg(cfg)
 
-        path = cfg.get("server", {}).get("cachedir", {})
         app.config[key] = cfg
 
+        # Set cachdir from configuration or default
+        path = cfg.get("server", {}).get("cachedir", {})
         app.cachedir = cachedir(appname, path)
 
         return app
